use cuddle_ci::cuddle_file::CuddleFile;
use cuddle_ci::rust_service::architecture::{Architecture, Os};
use cuddle_ci::rust_service::extensions::*;
use cuddle_ci::rust_service::RustService;
use cuddle_ci::{cuddle_please, CuddleCI};

#[tokio::main]
async fn main() -> eyre::Result<()> {
    dagger_sdk::connect(|client| async move {
        let cuddle_file = CuddleFile::from_cuddle_file().await?;

        let service = &RustService::from(client.clone())
            .with_arch(Architecture::Amd64)
            .with_os(Os::Linux)
            .with_apt(&["libssl-dev", "libz-dev", "libpq-dev", "protobuf-compiler"])
            .with_apt_release(&["libssl-dev", "libz-dev", "libpq-dev"])
            .with_cuddle_file(&cuddle_file)
            .with_apt_ca_certificates()
            .with_workspace_crates()
            .await
            .with_mold("2.3.3")
            .to_owned();

        let cuddle_please = &cuddle_please::CuddlePlease::new(client.clone());

        CuddleCI::default()
            .with_pull_request(service)
            .with_main(service)
            .with_main(cuddle_please)
            .execute(std::env::args())
            .await?;

        Ok(())
    })
    .await?;
    Ok(())
}
